%define ALD_Ver		1.2.1

Name:         libtheora

License:      BSD
Summary:      The Theora Video Compression Codec.
Group:        System Environment/Libraries
Version:      1.1.1
Release:      1
URL: http://www.theora.org/

Requires:	libogg >= 1.1
Requires:	libvorbis >= 1.0.1

Source: %{name}-%{version}.tar.xz
Source1: CROSS.sh
Patch0: libtheora-1.1.patch

%define DestDir		/Multimedia
# -----------------------------------------------------
%if %{_target_cpu} == %{_build_cpu}
%define _CROSS 0
%define BUILD_LOCAL_CROSS 0
%else
# rpm --target=x86_64 -ba xxxxx.spec
%define _CROSS 1
%define BUILD_LOCAL_CROSS 1
%endif

%define TO_ARCH %{_target_cpu}

%if %{_target_cpu} == "armv6l"
%define ARM_ARCH armv6zk
%define ARM_FPU  -mfpu=vfp -mfloat-abi=hard
%define TO_ARCH %{ARM_ARCH}
%endif

%if %{_target_cpu} == "armv7l"
%define ARM_ARCH armv7-a
%define ARM_FPU  -mfpu=vfpv3-d16 -mfloat-abi=hard
%define TO_ARCH %{ARM_ARCH}
%endif

%define BUILD_TAR 1
#------------------ CROSS DIR --------------------
%define _libdir	%{_prefix}/%{_lib}
%define _libexecdir	%{_libdir}/dbus-1.0

%if %{_CROSS}

%if %{_os} == "mingw"
ERROR: target=%{_os}
%define target %{_arch}-%{_vendor}-%{_os}%{__isa_bits}
%else  #win32 || win64
%define target %{_arch}-%{_os}%{_gnu}
%endif

%define crossdir	/cross
%if %{_arch} == "arm"
%define csysdir		%{crossdir}/%{ARM_ARCH}
%else
%define csysdir		%{crossdir}/%{_target_cpu}
%endif
%define csysbindir	%{csysdir}/bin
%define target_  %{target}-

%define __os_install_post %{nil}

%define cross_sysconfdir %{csysdir}%{_sysconfdir}
%define cross_bindir	%{csysdir}%{_bindir}
%define cross_sbindir	%{csysdir}%{_sbindir}
%define cross_libdir	%{csysdir}%{_libdir}
%define cross_includedir %{csysdir}%{_includedir}
%define cross_datadir	%{csysdir}%{_datadir}
%define cross_infodir	%{csysdir}%{_infodir}
%define cross_mandir	%{csysdir}%{_mandir}
%define cross_localstatedir %{csysdir}%{_localstatedir}
%define cross_defaultdocdir %{csysdir}%{_defaultdocdir}
%define cross_docdir	%{cross_defaultdocdir}/%{name}

%define CrossDestDir	/Cross

%define _srcrpmdir	%{_topdir}/SRPMS/tmp

%else  #_CROSS

%define csysdir		%{nil}
%define csysbindir	%{_prefix}/bin
%define CrossDestDir	%{nil}
%define _srcrpmdir	%{_topdir}/SRPMS/%{ALD_Ver}

%define target %{_build}
%define target_  %{nil}

%endif # !_CROSS

%define docdir %{_defaultdocdir}/%{name}
# ------------------- description ------------------------------------
%description
Theora is Xiph.Org's first publicly released video codec, intended
for use within the Ogg's project's Ogg multimedia streaming system.
Theora is derived directly from On2's VP3 codec; Currently the two are
nearly identical, varying only in encapsulating decoder tables in the
bitstream headers, but Theora will make use of this extra freedom
in the future to improve over what is possible with VP3.
#-------------------------------
%package devel
Summary:      Libraries for the C compiler
Group:        Development/Libraries
%description devel
These libraries are needed to compile C code.
#-------------------------------
%package doc
Summary:      doc for %{name}
Group:        Documentation
%description doc
doc for %{name}
#-------------------------------
%package %{TO_ARCH}
Summary:      %{name} Cross-%{TO_ARCH} Libraries
Group:        Development/Libraries
%description %{TO_ARCH}
%{name} Cross-%{TO_ARCH} Libraries

# ------------------- setup ------------------------------------------
%Prep
%setup -q
%patch0 -b .orig -p0

# ------------------- Build ------------------------------------------
%Build 
%if %{_CROSS}
PATH=%{csysbindir}:$PATH:/opt/perl/bin
GCC_NoHostPath=d
export PATH GCC_NoHostPath
%else
export PATH=$PATH:/opt/perl/bin
%endif

%if %{_arch} == "i386"
OPTFLAGS="-O2 -march=i486 -mpreferred-stack-boundary=2 -falign-functions=1 -falign-jumps=1 -falign-loops=1 -fomit-frame-pointer"
%endif
%if %{_arch} == "x86_64"
OPTFLAGS="-O2 -fno-asynchronous-unwind-tables"
%endif
%if %{_arch} == "arm"
OPTFLAGS="-O2 -march=%{ARM_ARCH} %{ARM_FPU} -munaligned-access"
%endif

CFLAGS="$OPTFLAGS -ffunction-sections -fdata-sections"
LDFLAGS="-Wl,--gc-sections"

export PKG_CONFIG_PATH=" "

%configure \
	--build=%{_build} \
%if %{_CROSS}
	--host=%{target} \
%endif
	--enable-shared \
	--disable-static \
	--disable-examples \
	--disable-libtool-lock \
	&>FConfigure_log.txt


make &>FMake_log.txt

# ------------------- Install ----------------------------------------
%Install
%if %{_CROSS}
PATH=%{csysbindir}:$PATH:/opt/perl/bin
GCC_NoHostPath=d
export PATH GCC_NoHostPath
%else
export PATH=$PATH:/opt/perl/bin
%endif

rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT
mkdir -p %{_srcrpmdir}
mkdir -p $RPM_BUILD_ROOT%{docdir}

make DESTDIR=$RPM_BUILD_ROOT install &>FInstall_log.txt

rm -rf $RPM_BUILD_ROOT%{_defaultdocdir}/%{name}-%{version}/latex
rm $RPM_BUILD_ROOT%{_libdir}/*.la

mv $RPM_BUILD_ROOT%{_defaultdocdir}/%{name}-%{version} $RPM_BUILD_ROOT%{docdir}/html

cp AUTHORS CHANGES COPYING LICENSE README $RPM_BUILD_ROOT%{docdir}/

%if %{_CROSS}
TARGET_PRFIX=%{_prefix}
TARGET_CROSS_PRFIX=%{csysdir}
TARGET_NAME=%{target}
MKCROSSDIR=%{BUILD_LOCAL_CROSS}
export TARGET_PRFIX TARGET_CROSS_PRFIX TARGET_NAME MKCROSSDIR
%SOURCE1
%if %{BUILD_LOCAL_CROSS}
rm -r $RPM_BUILD_ROOT%{cross_docdir}/html
%endif #BUILD_LOCAL_CROSS
%endif #_CROSS

%if !%{_CROSS}
if test -f /opt/aldccp/bin/packages_idx; then
  /opt/aldccp/bin/packages_idx -p %{name} -v %{version} $RPM_BUILD_ROOT
fi
%endif

# ------------------- Clean ------------------------------------------
%Clean 
DE=%{version}-%{release}.%{TO_ARCH}.rpm
DD=%{_rpmdir}/%{TO_ARCH}/%{ALD_Ver}%{DestDir}
DEC=%{version}-%{release}.%{_build_cpu}.rpm
DDC=%{_rpmdir}/%{_build_cpu}/%{ALD_Ver}%{CrossDestDir}/%{TO_ARCH}%{DestDir}

pushd %{_rpmdir}/%{_target_cpu}
  SE=%{version}-%{release}.%{_target_cpu}.rpm
  mkdir -p $DD
  mv %{name}-$SE $DD/%{name}-$DE
  mv %{name}-devel-$SE $DD/%{name}-devel-$DE
  mv %{name}-doc-$SE $DD/%{name}-doc-$DE
%if %{BUILD_LOCAL_CROSS}
  mkdir -p $DDC
  mv %{name}-%{TO_ARCH}-$SE $DDC/%{name}-%{TO_ARCH}-$DEC
%endif #BUILD_LOCAL_CROSS
popd

# --------------- build *.tgz ------------------------
%if %{BUILD_TAR}
pushd $RPM_BUILD_ROOT
  TMP_TO=$DD/tar
  mkdir -p $TMP_TO
  tmp=%{name}-%{version}-%{release}.%{TO_ARCH}
  mkdir -p $tmp
  cp -r usr $tmp/
  tar -cjf $tmp.tar.bz2 $tmp
  mv $tmp.tar.bz2 $TMP_TO
  rm -r $tmp
%if %{BUILD_LOCAL_CROSS}
  TMP_TO=$DDC/tar
  mkdir -p $TMP_TO
  tmp=%{name}-%{TO_ARCH}-%{version}-%{release}.%{_build_cpu}
  mkdir -p $tmp
  cp -r cross $tmp/
  tar -cjf $tmp.tar.bz2 $tmp
  mv $tmp.tar.bz2 $TMP_TO
  rm -r $tmp
%endif
popd
%endif  #BUILD_TAR

# ------------------- Files ------------------------------------------
%Files
%{_libdir}/*.so.*
%{docdir}/AUTHORS
%{docdir}/CHANGES
%{docdir}/COPYING
%{docdir}/LICENSE
%{docdir}/README

%files devel
%{_includedir}
%{_libdir}/*.so
%{_libdir}/pkgconfig

%files doc
%{docdir}/html

# ------------------- Cross Files ------------------------------------
%if %{BUILD_LOCAL_CROSS}

%Files %{TO_ARCH}
%{cross_libdir}
%{cross_includedir}
%{cross_docdir}

%endif #!BUILD_LOCAL_CROSS
